@@ -38,7 +38,8 @@ def combine(in_files, out_file, verbose=False, replace = None):
 
         if replace:
             for k in replace.keys():
-                data = data.replace(k, replace.get(k))
+                data = re.sub(k, replace.get(k), data)
+                #data = data.replace(k, replace.get(k))
 
         fh.close()
    
@@ -174,7 +175,8 @@ def deepcopy(file_list, folder, replace = None):
             data = fh.read()
         
             for k in replace.keys():
-                data = data.replace(k, replace.get(k))
+                data = re.sub(k, replace.get(k), data)
+                #data = data.replace(k, replace.get(k))
 
             fh.close()
             writefile(dst_file, data, os.path.getmtime(file))
